#! /usr/bin/env python
# -*- coding: utf-8 -*-

import numpy as np
import numpy.ma as ma
from netCDF4 import Dataset
import sys
import matplotlib as mpl
import matplotlib.pyplot as plt
import datetime
import matplotlib.patches as patches
import matplotlib.colors as colors
from matplotlib.ticker import MultipleLocator, FormatStrFormatter
import matplotlib.dates as mdates


#3 options possible when calling this script:
#option_yaxis: "d" or "s" for vertical axis 
#   in snow  heights or equivalent water heights
# var: SNOWRO, SNOWTEMP, SNOWSSA, DELTA18O_FAR etc... --> variable name
# option_diff: "fixe18_-vap" or "vap_pvar": variable value or variable change

var = 'SNOWRO'
missing = -9999999.
option_yaxis =  "d"  # toggle for depth/SWE vertical axis
option_diff='fixe18_-vap'
 
if len(sys.argv) > 1 : option_yaxis = sys.argv[1]
if len(sys.argv) > 2 : var = sys.argv[2]
if len(sys.argv) > 3 : option_diff = sys.argv[3]


#Please check that the PRO.nc file contains less than 500 days
#If there are more than 500 days, reduce the file with ncks:
#ncks -d time,0,3650,7 PRO.nc PRO_weekly.nc

file_names=['PRO_weekly_GR_end2010_Tvaries_DV0varies.nc']


for name in file_names:
    stordata=name
    fh=Dataset(stordata,mode='r')
    time=fh.variables['time'][:]
    lats=fh.variables['lat'][:]
    lons=fh.variables['lon'][:]
    SNOWDZ=fh.variables['SNOWDZ'][:]
    SNOWTEMP=fh.variables['SNOWTEMP'][:]
    SNOWRO=fh.variables['SNOWRO'][:]
    DELTA18O_BULK=fh.variables['DELTA18O_BULK'][:]
    DELTA18O_FAR=fh.variables['DELTA18O_FAR'][:]
    DEX_BULK=fh.variables['DEX_BULK'][:]
    DEX_FAR=fh.variables['DEX_FAR'][:]
    X17OEX_BULK=fh.variables['X17OEX_BULK'][:]
    X17OEX_FAR=fh.variables['X17OEX_FAR'][:]
    siz=np.shape(SNOWRO)
    SNOWSSA=fh.variables['SNOWSSA'][:]
    fh.close()      
    if name=='PRO_weekly_GR_end2010_Tvaries_DV0varies.nc':  
        time1=np.zeros(siz[0])
        lats1=np.zeros(1)
        lons1=np.zeros(1)
        DZ1=np.zeros((siz[0],siz[1]))
        TEMP1=np.zeros((siz[0],siz[1]))
        RO1=np.zeros((siz[0],siz[1]))
        SSA1=np.zeros((siz[0],siz[1]))
        D18OB1=np.zeros((siz[0],siz[1]))
        D18OF1=np.zeros((siz[0],siz[1]))
        DEXB1=np.zeros((siz[0],siz[1]))
        DEXF1=np.zeros((siz[0],siz[1]))
        X17B1=np.zeros((siz[0],siz[1]))
        X17F1=np.zeros((siz[0],siz[1]))       
        time1[:],lats1[:],lons1[:]=time[:],lats[:],lons[:]
        DZ1[:],TEMP1[:],RO1[:]=SNOWDZ[:,:,0,0],SNOWTEMP[:,:,0,0],SNOWRO[:,:,0,0]
        D18OB1[:], SSA1[:]=DELTA18O_BULK[:,:,0,0],SNOWSSA[:,:,0,0]
        D18OF1[:]=DELTA18O_FAR[:,:,0,0]
        DEXF1[:], DEXB1[:]=DEX_FAR[:,:,0,0], DEX_BULK[:,:,0,0]
        X17F1[:], X17B1[:]=X17OEX_FAR[:,:,0,0], X17OEX_BULK[:,:,0,0]

DZ1=ma.masked_values(DZ1,missing)
DZ1 = DZ1.filled(0.)  # fill missing values with zeroes
H1 = ma.zeros(DZ1.shape)
nmax = np.shape(H1)[1]

H1[:,-1] = DZ1[:,-1]
for i in range(nmax-2,-1,-1) :
  H1[:,i] = H1[:,i+1] + DZ1[:,i]

DZ12=DZ1
H12=H1
time12=time1

time_2 = np.ones(time12.shape,datetime.datetime)
for i in range(len(time1)):
	time_2[i] = datetime.datetime(1900,1,1,0,0,0) + datetime.timedelta(seconds=time12[i])
dtime = time12[2] - time12[1]
dtime_2 = datetime.timedelta(seconds=dtime/2.)


##toggle in case of SWE vertical awis:
if option_yaxis == "s":
	DZ1=DZ1*RO1

TEMP12=TEMP1
RO12=RO1
D18OB12=D18OB1
D18OF12=D18OF1

#variable tarnsformation for the time plot
DZ1=ma.masked_values(DZ1,missing)
DZ12=ma.masked_values(DZ12,missing)

if var=='SNOWTEMP':       
    ROCHANGE=TEMP1
    ROCHANGE=ma.masked_values(ROCHANGE,missing)
    
if var=='SNOWRO':
    RO1=ma.masked_values(RO1,missing)

    if   option_diff=='fixe18_-vap':   #nothing
        ROCHANGE=np.zeros(np.shape(DZ1))
        ROCHANGE[:]=RO1[:]
        print ROCHANGE[5:8,5:8]
    elif option_diff=='vap_pvar':      #vapcomp-comp
        ROCHANGE=np.zeros(np.shape(DZ12))
        for t in range(np.shape(time12)[0]-1):
            for z in range(int(np.shape(DZ12)[1])):
                 if not DZ12[t+1,z]==0:
                    ROCHANGE[t+1,z]=RO12[t+1,z]-RO12[0,z]
    else:
        print option_diff, 'is not a valid option'
        ROCHANGE=np.zeros((siz[0],siz[1]))
        ROCHANGE=ma.masked_values(ROCHANGE,missing)
elif var=='DEX_BULK':
    DEXB1=ma.masked_values(DEXB1,missing)
    if   option_diff=='fixe18_-vap':   #nothing
        ROCHANGE=DEXB1
elif var=='DEX_FAR':
    DEXF1=ma.masked_values(DEXF1,missing)
    if   option_diff=='fixe18_-vap':   #nothing
        ROCHANGE=DEXF1
elif var=='X17OEX_BULK':
    X17B1=ma.masked_values(X17B1,missing)
    if   option_diff=='fixe18_-vap':   #nothing
        ROCHANGE=X17B1
elif var=='X17OEX_FAR':
    X17F1=ma.masked_values(X17F1,missing)
    if   option_diff=='fixe18_-vap':   #nothing
        ROCHANGE=X17F1
    
elif var=='DELTA18O_BULK':
    D18OB1=ma.masked_values(D18OB1,missing)    
    if   option_diff=='fixe18_-vap':   #nothing
        ROCHANGE=D18OB1
    elif option_diff=='vap_pvar':      #vapcomp-comp
        ROCHANGE=np.zeros(np.shape(DZ12))
        for t in range(np.shape(time12)[0]-1):
            for z in range(np.shape(DZ12)[1]):
                if not DZ12[t+1,z]==0:
                   ROCHANGE[t+1,z]=D18OB12[t+1,z]+40.
    else:
        print option_diff, 'is not a valid option'
        ROCHANGE=np.zeros((siz[0],siz[1]))
        ROCHANGE=ma.masked_values(ROCHANGE,missing)
elif var=='DELTA18O_FAR':
    D18OF1=ma.masked_values(D18OF1,missing)
    if   option_diff=='fixe18_-vap':   #nothing
        ROCHANGE=D18OF1
    elif option_diff=='vap_pvar':      #vapcomp-comp
        ROCHANGE=np.zeros(np.shape(DZ12))
        for t in range(np.shape(time12)[0]-1):
            for z in range(np.shape(DZ12)[1]):
                if not DZ12[t+1,z]==0:
                    ROCHANGE[t+1,z]=D18OF12[t+1,z]-D18OF12[1,z]
                    
        print ROCHANGE[:,14]
        print ROCHANGE[:,12]
        #Create a .txt file with the d18O values for 4 layers
        for t in range(np.shape(time12)[0]):
            for z in range(np.shape(DZ12)[1]):
              if DZ12[t,z]>0.01:
                fichier = open("list_winter_summer.txt", "a")
                #layer "winter 2000"
                if D18OF12[t,z]<-52.:
                    if H12[t,z]<11.665 and H12[t,z]>11.663:
                        fichier.write('winter0 ')
                        fichier.write(str(t))
                        fichier.write(';   ')
                        fichier.write(str(z))
                        fichier.write(';   ')
                        fichier.write(str(DZ12[t,z]))
                        fichier.write(';   ')
                        fichier.write(str(H12[t,z]))
                        fichier.write(';   ')
                        fichier.write(str(D18OF12[t,z]))
                        fichier.write('\n')
                elif D18OF12[t,z]>-45.:
                    #layer "summer 2002"
                    if H12[t,z]<11.855 and H12[t,z]>11.853:
                        fichier.write('summer1 ')
                        fichier.write(str(t))
                        fichier.write(';   ')
                        fichier.write(str(z))
                        fichier.write(';   ')
                        fichier.write(str(DZ12[t,z]))
                        fichier.write(';   ')
                        fichier.write(str(H12[t,z]))
                        fichier.write(';   ')
                        fichier.write(str(D18OF12[t,z]))
                        fichier.write('\n')
                      #layer "summer 2004"  
                    if H12[t,z]<12.039 and H12[t,z]>12.037:
                        fichier.write('summer2 ')
                        fichier.write(str(t))
                        fichier.write(';   ')
                        fichier.write(str(z))
                        fichier.write(';   ')
                        fichier.write(str(DZ12[t,z]))
                        fichier.write(';   ')
                        fichier.write(str(H12[t,z]))
                        fichier.write(';   ')
                        fichier.write(str(D18OF12[t,z]))
                        fichier.write('\n')
                    if H12[t,z]<12.271 and H12[t,z]>12.269:
                        #layer "summer 2006"
                        fichier.write('summer3 ')
                        fichier.write(str(t))
                        fichier.write(';   ')
                        fichier.write(str(z))
                        fichier.write(';   ')
                        fichier.write(str(DZ12[t,z]))
                        fichier.write(';   ')
                        fichier.write(str(H12[t,z]))
                        fichier.write(';   ')
                        fichier.write(str(D18OF12[t,z]))
                        fichier.write('\n')                    
                fichier.close()                 
    else:
        print option_diff, '  is not a valid option'
        ROCHANGE=np.zeros((siz[0],siz[1]))
        ROCHANGE=ma.masked_values(ROCHANGE,missing)

time12 = ma.masked_values(time12, missing) #ref time scale
DZif=DZ12
TEMPif=TEMP12
ROCHANGE=ma.masked_values(ROCHANGE,missing)

#Plot of the new variable 
#print np.shape(DZ),np.shape(time1),np.shape(ROCHANGE)
if len(time12) > 550:
   print "too many points ; reduce the time resolution of the PRO.nc file"
   print "ncks -d time,0,3650,7 PRO.nc PRO_weekly.nc"
   sys.exit()

#Handling of time information
time_2 = np.ones(time12.shape,datetime.datetime)
for i in range(len(time12)):
	time_2[i] = datetime.datetime(1900,1,1,0,0,0) + datetime.timedelta(seconds=time12[i])
dtime = time12[2] - time12[1]
dtime_2 = datetime.timedelta(seconds=dtime/2.)


#Definition of bounds for the variable
Vmin = np.min(ROCHANGE[:,:60])
Vmax = np.max(ROCHANGE[:,:60])
bounds=[Vmin, Vmax]
print 'bounds_automatic', bounds
#Vmin=-18.
#Vmax=-2.
bounds=[Vmin, Vmax]
print 'bounds_user', bounds


#Params for the conversion from values to [0,1] and then to colors
###Linear scale from Vmin to Vmax

if (option_diff=='fixe18_-vap' ):
    linear=True
elif (option_diff=='vap_pvar'  ):
    linear=False
else:
    linear=True


if linear== True:
    print 'linear scale'
    Norm=colors.Normalize(vmin=Vmin, vmax=Vmax) #to [0,1]
    Cmap=mpl.cm.jet    #Rainbow
    scmap=mpl.cm.ScalarMappable(norm=Norm,cmap=Cmap)#to colors

#Parms for the conversion from values to [0,1] and then to colors
###Two linear scales for Vmin to zero and then from zero to Vmax
else:
  if Vmin*Vmax<=0:
      if Vmin==0:
          Vmin=-0.0001
      elif Vmax==0:
          Vmax=0.0001
      print 'bilinear scale'
      class MidpointNormalize(colors.Normalize):
        def __init__(self, vmin=None, vmax=None, midpoint=None, clip=False):
           self.midpoint = midpoint
           colors.Normalize.__init__(self, vmin, vmax, clip)

        def __call__(self, value, clip=None):
           x, y = [self.vmin, self.midpoint, self.vmax], [0, 0.5, 1]
           return np.ma.masked_array(np.interp(value, x, y))

      Norm=MidpointNormalize(vmin=Vmin, vmax=Vmax, midpoint=0.)#to [0,1]
      Cmap="RdBu_r"    #Blue to red
      scmap=mpl.cm.ScalarMappable(norm=Norm,cmap=Cmap)#to colors
  else:
      print 'BEWARE: bilinear scale only if values both sides of 0'
      print 'with a linear scale'
      Norm=colors.Normalize(vmin=Vmin, vmax=Vmax) #to [0,1]
      Cmap="RdBu_r"
      scmap=mpl.cm.ScalarMappable(norm=Norm,cmap=Cmap)#to colors


#General variables for plotting

####For the figure
cases=8 #:8panels
#cases=3  #:3panels
#cases=2 #:2panels

fig=plt.figure()
if cases==2:
    ax1=plt.subplot2grid((1,8),(0,0),colspan=3)
    ax2=plt.subplot2grid((1,8),(0,3),colspan=5)
    fig.set_size_inches(18.,8.)
else:
    ax1=plt.subplot2grid((1,8),(0,0),colspan=1)
    ax2=plt.subplot2grid((1,8),(0,4),colspan=4)
    fig.set_size_inches(18.,8.)

tut= 11.9   #11.75  #11.9  11.66 11.69
tit= 10.6  #11.35  #10.6   11.6 11.6 
ax1.set_ylim(tit, tut)
ax2.set_ylim(tit, tut) #!Same as ax1!!
ax1.get_yaxis().get_major_formatter().set_useOffset(False)
ax2.get_yaxis().get_major_formatter().set_useOffset(False)

if cases==8:
    ax3=plt.subplot2grid((1,8),(0,1),colspan=1)
    ax4=plt.subplot2grid((1,8),(0,2),colspan=2)
    #ax5=plt.subplot2grid((1,8),(0,3),colspan=1)
    ax3.set_ylim(tit, tut) #!Same as ax1!!
    ax4.set_ylim(tit, tut)  #!Same as ax1!!
    #ax5.set_ylim(tit, tut)  #!Same as ax1!!
elif cases==3:
    ax4=plt.subplot2grid((1,8),(0,1),colspan=3)
    ax4.set_ylim(tit, tut)  #!Same as ax1!!

#plt.xlim(datetime.datetime(2002,6,15),datetime.datetime(2002,9,15))


####For the left graph (ax1)
colors=['black', 'grey', 'purple', 'blue', 'deepskyblue', 'green','yellow','orange', 'red','brown', 'black','grey']
symbol=[  '-', '-', '-',  '-', '-', '-', '-', '-', '-',  '-', '-', '-' ]
hour  =[ '2000', '2001','2002', '2003','2004', '2005','2006', '2007','2008', '2009','2010','2011' ]
#hour=[30,60,90,120,150,180,210,240]
symbol=[  '-', '-', '-',  '-', '-', '-', '-', '-', '-',  '-', '-', '-' ]
markersize=[6,6,6,6,6,6,6,6,6,6,6,6]
markertype=['o','o','o','o','o','o','o','o','o','o','o','o']
date=[1,54, 52*2+2, 53*3-1, 52*4+2,  52*5+2, 52*6+2, 52*7+3, 52*8+3, 52*9+3]
#date=[30,60,90,120,150,180,210,240]
markertypex=['o','o','o','o','o','^','^','^','^','^']

print np.shape(ROCHANGE)
#for n in range(len(date)-1,-1,-1):
for n in range(len(date)):
    t_ax1=date[n]
    line,=ax1.plot(TEMP12[t_ax1,:],H12[t_ax1,:]-DZ12[t_ax1,:]/2.,                           label='Inline label',      linestyle=symbol[n], color=colors[n])
    #topeach,=ax1.plot(TEMP12[t_ax1,0],H12[t_ax1,0]-DZ12[t_ax1,0]/2.,                              linestyle=symbol[n], color=colors[n], label='Inline label',                               marker=markertypex[n], ms=8, mew=1)
    line.set_label(hour[n])
    #ax1.legend(loc=4,ncol=1,columnspacing=1,fontsize=19,handlelength=0.8,
    #                 handletextpad=0.2, borderpad=0.2,frameon=False)
    if cases==8:
        linero,=ax3.plot(D18OF12[t_ax1,:],H12[t_ax1,:]-DZ12[t_ax1,:]/2.,                              linestyle=symbol[n], color=colors[n], label='Inline label',                      marker=markertype[n], ms=markersize[n], mew=0.3)
        #linera,=ax3.plot(ROCHANGE[t_ax1,0],H[t_ax1,0]-DZif[t_ax1,0]/2.,                              linestyle=symbol[n], color=colors[n], label='Inline label',                                marker='+', ms=15, mew=2)
        lineru,=ax4.plot(ROCHANGE[t_ax1,:],H12[t_ax1,:]-DZ12[t_ax1,:]/2.,                            linestyle=symbol[n], color=colors[n], label='Inline label')
        #,                   marker=markertype[n], ms=markersize[n], mew=0.3)
        #linery,=ax5.plot(ROCHANGE[t_ax1,:],H1[t_ax1,:]-DZif[t_ax1,:]/2.,                              linestyle=symbol[n], color=colors[n], label='Inline label',                         marker=markertype[n], ms=markersize[n], mew=0.3)
        #macro= np.argmax(ROCHANGE[t_ax1,:50])
        #print t_ax1, macro
        #linerao,=ax5.plot(ROCHANGE[t_ax1,macro],H[t_ax1,macro]-                                              DZif[t_ax1,macro]/2.,                                           linestyle=symbol[n], color=colors[n],                                 marker='+', ms=15, mew=2)
        #lineru.set_label(hour[n])
        #handles, labels=ax4.get_legend_handles_labels()
        #ax4.legend(handles[::-1],labels[::-1],loc=2,ncol=1,columnspacing=1,                                  fontsize=19,handlelength=1.3,                                                 handletextpad=0.2, borderpad=0.2,frameon=False)
    elif cases==3:    
        lineru,=ax4.plot(D18OF1[t_ax1,:],H12[t_ax1,:]-DZ12[t_ax1,:]/2.,                              linestyle=symbol[n], color=colors[n], label='Inline label',                           marker=markertype[n], ms=markersize[n], mew=1)
        lineru.set_label(hour[n])
        ax4.legend(loc=3,ncol=3,columnspacing=1,fontsize=19,handlelength=1.3,
                     handletextpad=0.2, borderpad=0.2,frameon=False)
    else:
        topeach.set_label(hour[n])
        ax1.legend(loc=2,ncol=4,columnspacing=1,fontsize=19,handlelength=0.5,
                     handletextpad=0.2, borderpad=0.2,frameon=False)
      
#‘best’	        0
#‘upper right’	1
#‘upper left’	2
#‘lower left’	3
#‘lower right’	4
#‘right’	5
#‘center left’	6
#‘center right’	7
#‘lower center’	8
#‘upper center’	9
#‘center’	10   
    print '-  ', time_2[t_ax1] #GMT hour
  
ax1.set_xlim(245.,270.0)         #Limits Temperature
ax1.get_xaxis().get_major_formatter().set_useOffset(False)
if option_yaxis == "d": ax1.set_ylabel('Snow height /m',fontsize=22)
if option_yaxis == "s": ax1.set_ylabel('Snow water equivalent /kg m${-3}$',fontsize=22)
ax1.set_xlabel('Temperature',family='serif',fontsize=22)
ax1.set_xticks([ 250., 265.])
ax1.tick_params(axis='both', which='major', labelsize=22, size=7, width=2)

if cases==3:
    mid= -35 #-45.
    Vmin = (min(ROCHANGE.compressed())-mid)*1.02+mid
    Vmax = (max(ROCHANGE.compressed())-mid)*1.02+mid
    ax4.set_xlim(-44., -27.)         #Limits
    #step=int((Vmax-Vmin)/8.)
    #mid=int((Vmax+Vmin)/2.)
    #print mid, 'nouveau mid'
    #liste_ticks=np.zeros(4)
    #liste_ticks[0]=mid-3*step
    #for n in range(3):
    #        liste_ticks[n+1]=liste_ticks[n]+2*step
    #ax4.set_xticks(liste_ticks) 
    ax4.get_xaxis().get_major_formatter().set_useOffset(False)
    ax4.get_yaxis().set_visible(False)
    ax4.tick_params(axis='both', which='major',labelsize=22,size=7, width=2)
    if (var=='DELTA18O_BULK' and option_diff=='vap_pvar'):
        ax4.set_xlabel('${\delta}^{18}O_{gsurf}$ change (per mil)',                                    fontsize=22, family='serif')
    elif (var=='DELTA18O_FAR' and option_diff=='vap_pvar'):
        ax4.set_xlabel('${\delta}^{18}O_{gcenter}$ change (per mil)',                                    fontsize=22, family='serif')
    elif (var=='DELTA18O_BULK' and option_diff=='fixe18_-vap'):
        ax4.set_xlabel('${\delta}^{18}O_{gsurf}$ (per mil)',                                    fontsize=22, family='serif')
    elif (var=='DELTA18O_FAR' and option_diff=='fixe18_-vap'):
        ax4.set_xlabel('${\delta}^{18}O_{gcenter}$ (per mil)',                                    fontsize=22, family='serif')
    elif (var=='SNOWRO' and option_diff=='vap_pvar'):
        ax4.set_xlabel('Density change (kg.m$^{-3}$)',fontsize=22)
    else:
        ax4.set_xlabel('Density (kg.m$^{-3}$)',fontsize=22)
elif cases==8:
    Vmin = min(ROCHANGE.compressed())
    Vmax = max(ROCHANGE.compressed())   
    if Vmin<0.:
        ax3.set_xlim(-44.,-27.)
        ax3.set_xticks([-35.5],minor=True) 
        ax3.set_xticks([-44.,-27.]) 
        print 'mid 0'
        ax4.set_xlim(-2.,2.)
        ax4.set_xticks([-1.5, 0., 1.5]) 
    elif Vmin<250.:
        mid=0.
        print 'mid 0'
        Vmin = min(ROCHANGE.compressed())*1.02
        Vmax = max(ROCHANGE.compressed())*1.02 
        lim_bas=mid-(mid-Vmin)/10.
        lim_haut=mid+(Vmax-mid)/10.
        lim_haut=mid+min(abs(lim_bas-mid),abs(lim_haut-mid))
        lim_bas=mid-min(abs(lim_bas-mid),abs(lim_haut-mid))
        #lim_haut=0.002
        #lim_bas=-0.002
        #Vmin=-0.700
        #Vmax=0.06
        xtick1=np.round(    Vmin                    ,3)
        xtick2=np.round(    (Vmin+lim_bas)/2.       ,3)
        xtick3=np.round(    lim_bas                 ,3)
        xtick4=np.round(    lim_haut                ,3)
        xtick5=np.round(    (lim_haut+Vmax)/2.      ,3)
        xtick6=np.round(    Vmax                    ,3)
        ax3.set_xlim(xtick1,xtick3)
        ax4.set_xlim(xtick3,xtick4)
        ax5.set_xlim(xtick4,xtick6)   
        ax3.set_xticks([xtick2],minor=True) 
        ax4.set_xticks([xtick3,xtick4],minor=True) 
        ax5.set_xticks([xtick5],minor=True)
        ax3.set_xticks([xtick1,xtick3]) 
        ax4.set_xticks([mid]) 
        ax5.set_xticks([xtick4,xtick6])
    else:
        mid= 304.
        print 'mid 304'
        Vmin = 296.85
        Vmax = 311.8
        #Vmax = (max(ROCHANGE.compressed())-mid)*1.02+mid
        ax3.set_xlim(296.85,297.15)
        ax4.set_xlim(303.7,304.3)
        ax5.set_xlim(311.2,311.8)   
        ax3.set_xticks([297.00],minor=True) 
        ax4.set_xticks([303.7,304.3],minor=True) 
        ax5.set_xticks([311.5],minor=True)
        ax3.set_xticks([296.85,297.15]) 
        ax4.set_xticks([mid]) 
        ax5.set_xticks([311.2,311.8])
    ax3.get_xaxis().get_major_formatter().set_useOffset(False)
    ax3.get_yaxis().set_visible(False)
    ax3.xaxis.tick_top()
    ax3.tick_params(axis='both', which='both',labelsize=22,size=7,                                   width=2, bottom=True)
    ax4.get_xaxis().get_major_formatter().set_useOffset(False)
    ax4.get_yaxis().set_visible(False)
    ax4.xaxis.tick_top()
    ax4.tick_params(axis='both', which='both',labelsize=22,                                          size=7, width=2, bottom=True, labelbottom=True)
    ax4.set_xlabel('${\delta}^{18}O_{gcenter}$ change (per mil)',                                    fontsize=22, family='serif')
    ## if (var=='DELTA18O_BULK' and option_diff=='vap_pvar'):
    ##     ax4.set_xlabel('${\delta}^{18}O_{gsurf}$ change (per mil)',                                    fontsize=22, family='serif')
    ## elif (var=='DELTA18O_FAR' and option_diff=='vap_pvar'):
    ##     ax4.set_xlabel('${\delta}^{18}O_{gcenter}$ change (per mil)',                                    fontsize=22, family='serif')
    ## elif (var=='DELTA18O_BULK' and option_diff=='fixe18_-vap'):
    ##     ax4.set_xlabel('${\delta}^{18}O_{gsurf}$ (per mil)',                                    fontsize=22, family='serif')
    ## elif (var=='DELTA18O_FAR' and option_diff=='fixe18_-vap'):
    ##     ax4.set_xlabel('${\delta}^{18}O_{gcenter}$ (per mil)',                                    fontsize=22, family='serif')
    ## elif (var=='SNOWRO' and option_diff=='vap_pvar'):
    ##     ax4.set_xlabel('Density change (kg.m$^{-3}$)',fontsize=22)
    ## else:
    ##     ax4.set_xlabel('Density (kg.m$^{-3}$)',fontsize=22)
    #ax5.get_xaxis().get_major_formatter().set_useOffset(False)
    #ax5.xaxis.tick_top()
    #ax5.get_yaxis().set_visible(False)
    #ax5.tick_params(axis='both', which='both',labelsize=22,                                             size=7, width=2, bottom=True)
    
####For the right graph
##Plot of the surface of the snow
ax2.plot(time_2[:],H12[:,0],'k-',lw=1.)#Plot of total snow height
ax2.set_xlabel('Date',family='serif',fontsize=22)
ax2.yaxis.tick_right()
ax2.xaxis_date()
ax2.xaxis.set_major_locator(mpl.dates.MonthLocator(bymonth=1,bymonthday=1,interval=12))
ax2.xaxis.set_major_formatter(mpl.dates.DateFormatter('%Y\n%m'))
ax2.tick_params(axis='both', which='major', labelsize=22, size=7, width=2)
for label in ax2.get_xticklabels()[:11:2]:
    label.set_visible(False)

##Plot of rectangles (rho values)
width = dtime/86400.
deb=0
timelo=[]
for i in range(len(time_2[deb:])):
	for j in range(80):
                start=mdates.date2num(time_2[deb+i]-dtime_2)
		coord = (start,H12[deb+i,j]) #date, height of top left corner
		height = - DZ12[deb+i,j]  # thickness of the layer
            #(negative since we give the top of the layer, not its bottom)
                eddie=scmap.to_rgba(ROCHANGE[deb+i,j])
		p = patches.Rectangle(coord,width,height,edgecolor = eddie,
                         fill = True, facecolor = eddie, linewidth = 0.)
	       	ax2.add_patch(p)
        if i in date:
          for n in range(len(date)):
              if i==date[n]:
                  coloru=colors[n]          
          for j in range(nmax):
              timelo.append(time_2[deb+i])
          ax2.plot(timelo[:], H12[deb+i,:],linestyle='--',color=coloru)
          timelo=[]
             

#Position                
if cases==2:
    ax8=fig.add_axes([0.54, 0.85, 0.26, 0.02])
else:
    ax8=fig.add_axes([0.58, 0.85, 0.26, 0.02])
#Orientation + Formatter scientific numbers (cbar)
def fmt(x,pos):
    a,b='{:.3e}'.format(x).split('e')
    b=int(b)
    return r'${} \times 10^{{{}}}$'.format(a, b)
cbar=mpl.colorbar.ColorbarBase(ax8,cmap=Cmap,norm=Norm,ticks=bounds,orientation='horizontal', format=mpl.ticker.FuncFormatter(fmt))

coloriage='black'

#Police of the xtick labels
obj=plt.getp(ax8, 'xticklabels')
plt.setp(obj,color=coloriage,fontsize=22)

#Label of the colorbar
if var=='SNOWRO':
    if linear==True:
        cbar.set_label('Density (kg.m$^{-3}$)',color=coloriage,
                                        fontsize=22, family='serif')
    else:
        cbar.set_label('Density change (kg.m$^{-3}$)',color=coloriage,
                                        fontsize=22, family='serif')
elif var=='DELTA18O_BULK':
    if linear==True:
        cbar.set_label('${\delta}^{18}O_{gsurf}$ (per mil)',
                         color=coloriage, fontsize=22, family='serif')
    else:
        cbar.set_label('${\delta}^{18}O_{gsurf}$ change (per mil)',
                         color=coloriage, fontsize=22, family='serif')

elif var=='DELTA18O_FAR':
    if linear==True:
        cbar.set_label('${\delta}^{18}O_{gcenter}$ (per mil)',
                         color=coloriage, fontsize=22, family='serif')
    else:
        cbar.set_label('${\delta}^{18}O_{gcenter}$ change (per mil)',
                         color=coloriage, fontsize=22, family='serif')
elif var=='DEX_FAR':
    if linear==True:
        cbar.set_label('$dex_{gcenter}$ (per mil)',
                         color=coloriage, fontsize=22, family='serif')
    else:
        cbar.set_label('$dex_{gcenter}$ change (per mil)',
                         color=coloriage, fontsize=22, family='serif')
elif var=='DEX_BULK':
    if linear==True:
        cbar.set_label('$dex_{gsurf}$ (per mil)',
                         color=coloriage, fontsize=22, family='serif')
    else:
        cbar.set_label('$dex_{gsurf}$ change (per mil)',
                         color=coloriage, fontsize=22, family='serif')


#plt.show()
plt.savefig('%s____%s.png'%(var,option_diff),dpi=300)

